@@ -94,7 +94,7 @@ class BaseDependency(object):
         preDepend = AttributeDeprecatedBy('pre_depend')
 
 
-class Dependency(object):
+class Dependency(list):
     """Represent an Or-group of dependencies.
 
     Attributes defined here:
@@ -102,11 +102,12 @@ class Dependency(object):
     """
 
     def __init__(self, alternatives):
-        self.or_dependencies = alternatives
-
-    def __repr__(self):
-        return repr(self.or_dependencies)
+        super(Dependency, self).__init__()
+        self.extend(alternatives)
 
+    @property
+    def or_dependencies(self):
+        return self
 
 class DeprecatedProperty(property):
     """A property which gives DeprecationWarning on access.
@@ -407,6 +408,17 @@ class Version(object):
         """Return the priority of the package, as string."""
         return self._cand.priority_str
 
+    @property
+    def policy_priority(self):
+        """Return the internal policy priority as a number.
+           See apt_preferences(5) for more information about what it means.
+        """
+        priority = 0
+        policy = self.package._pcache._depcache.policy
+        for (packagefile, _) in self._cand.file_list:
+            priority = max(priority, policy.get_priority(packagefile))
+        return priority
+
     @property
     def record(self):
         """Return a Record() object for this version.
@@ -454,6 +466,11 @@ class Version(object):
         """Return the recommends of the package version."""
         return self.get_dependencies("Recommends")
 
+    @property
+    def suggests(self):
+        """Return the suggests of the package version."""
+        return self.get_dependencies("Suggests")
+
     @property
     def origins(self):
         """Return a list of origins for the package version."""
@@ -528,7 +545,10 @@ class Version(object):
 
         .. versionadded:: 0.7.10
         """
-        return iter(self._uris()).next()
+        try:
+            return iter(self._uris()).next()
+        except StopIteration:
+            return None
 
     def fetch_binary(self, destdir='', progress=None):
         """Fetch the binary version of the package.
@@ -707,6 +727,9 @@ class Package(object):
         return '<Package: name:%r architecture=%r id:%r>' % (self._pkg.name,
                  self._pkg.architecture, self._pkg.id)
 
+    def __lt__(self, other):
+        return self.name < other.name
+
     def candidate(self):
         """Return the candidate version of the package.
 
@@ -1022,12 +1045,15 @@ class Package(object):
         Return a list of unicode names of the files which have
         been installed by this package
         """
-        path = "/var/lib/dpkg/info/%s.list" % self.name
-        try:
-            with open(path, "rb") as file_list:
-                return file_list.read().decode("utf-8").split(u"\n")
-        except EnvironmentError:
-            return []
+        for name in self.shortname, self.fullname:
+            path = "/var/lib/dpkg/info/%s.list" % name
+            try:
+                with open(path, "rb") as file_list:
+                    return file_list.read().decode("utf-8").split(u"\n")
+            except EnvironmentError:
+                continue
+
+        return []
 
     def get_changelog(self, uri=None, cancel_lock=None):
         """
