@@ -198,11 +198,13 @@ static PyObject *PkgCacheOpen(PyObject *Self,PyObject *Args)
    }
 
    //std::cout << "new cache is " << (pkgCache*)(*Cache) << std::endl;
+   
+   // ensure that the states are correct (LP: #659438)
+   pkgApplyStatus(*Cache);
 
    // update the cache pointer after the cache was rebuild
    ((CppPyObject<pkgCache*> *)Self)->Object = (pkgCache*)(*Cache);
 
-
    Py_INCREF(Py_None);
    return HandleErrors(Py_None);
 }
@@ -229,6 +231,12 @@ static PyObject *PkgCacheGetGroups(PyObject *Self, void*) {
    return CppPyObject_NEW<GrpListStruct>(Self,&PyGroupList_Type,Cache->GrpBegin());
 }
 
+static PyObject *PkgCacheGetPolicy(PyObject *Self, void*) {
+   pkgCacheFile *CacheFile = GetCpp<pkgCacheFile *>(Self);
+   std::cerr << "policy: " << CacheFile->Policy << std::endl;
+   return CppPyObject_NEW<pkgPolicy*>(Self,&PyPolicy_Type,CacheFile->Policy);
+}
+
 static PyObject *PkgCacheGetPackages(PyObject *Self, void*) {
    pkgCache *Cache = GetCpp<pkgCache *>(Self);
    return CppPyObject_NEW<PkgListStruct>(Self,&PyPackageList_Type,Cache->PkgBegin());
@@ -278,7 +286,7 @@ static PyObject *PkgCacheGetFileList(PyObject *Self, void*) {
 
 static PyObject *PkgCacheGetIsMultiArch(PyObject *Self, void*) {
     pkgCache *Cache = GetCpp<pkgCache *>(Self);
-    PyBool_FromLong(Cache->MultiArchCache());
+    return PyBool_FromLong(Cache->MultiArchCache());
 } 
 
 static PyGetSetDef PkgCacheGetSet[] = {
@@ -289,6 +297,7 @@ static PyGetSetDef PkgCacheGetSet[] = {
    {"group_count",PkgCacheGetGroupCount,0,
     "The number of apt_pkg.Group objects stored in the cache."},
    {"groups",  PkgCacheGetGroups, 0, "A list of Group objects in the cache"},
+   {"policy",  PkgCacheGetPolicy, 0, "The PkgPolicy for the cache"},
    {"is_multi_arch", PkgCacheGetIsMultiArch, 0,
     "Whether the cache supports multi-arch."},
    {"package_count",PkgCacheGetPackageCount,0,
@@ -394,6 +403,9 @@ static PyObject *PkgCacheNew(PyTypeObject *type,PyObject *Args,PyObject *kwds)
 	     return HandleErrors();
    }
 
+   // ensure that the states are correct (LP: #659438)
+   pkgApplyStatus(*Cache);
+
    CppPyObject<pkgCacheFile*> *CacheFileObj =
 	   CppPyObject_NEW<pkgCacheFile*>(0,&PyCacheFile_Type, Cache);
 
