@@ -17,8 +17,8 @@ sys.path.insert(0, get_library_dir())
 import apt_pkg
 import apt.debfile
 
-class TestDebfilee(unittest.TestCase):
-    """ test the apt cache """
+class TestDebfile(unittest.TestCase):
+    """ test the debfile """
 
     TEST_DEBS = [
         # conflicts with apt
@@ -87,12 +87,7 @@ class TestDebfilee(unittest.TestCase):
         self.assertEqual(deb["Maintainer"],
                          "Samuel Lidén Borell <samuel@slbdata.se>")
 
-    def testContent(self):
-        # no python-debian for python3 yet, so fail gracefully
-        try:
-            import debian
-        except ImportError:
-            return
+    def test_content(self):
         # normal
         deb = apt.debfile.DebPackage(cache=self.cache)
         deb.open(os.path.join("data", "test_debs", "gdebi-test11.deb"))
@@ -119,6 +114,12 @@ Description: testpackage for gdebi - contains usr/bin/binary for file reading
         deb = apt.debfile.DebPackage("./data/test_debs/data-tar-xz.deb")
         self.assertEqual(deb.filelist, ["./", "usr/", "usr/bin/"])
 
+    def test_check_exception(self):
+        deb = apt.debfile.DebPackage("./data/test_debs/data-tar-xz.deb")
+        self.assertRaises(AttributeError, lambda: deb.missing_deps)
+        deb.check()
+        deb.missing_deps
+
     def test_no_supported_data_tar(self):
         # ensure that a unknown data.tar.xxx raises a exception
         raised = False
@@ -130,6 +131,7 @@ Description: testpackage for gdebi - contains usr/bin/binary for file reading
 	# we need to support python2.6
         self.assertTrue(raised)
 
+
 if __name__ == "__main__":
     #logging.basicConfig(level=logging.DEBUG)
     unittest.main()
