@@ -40,8 +40,8 @@ for entry in d.entries:
         countries[countrycode].add(link.href)
 
 
-keys = countries.keys()
-keys.sort()
+keys = sorted(countries)
+print("mirror://mirrors.ubuntu.com/mirrors.txt")
 for country in keys:
-    print "#LOC:%s" % country
-    print "\n".join(sorted(countries[country]))
+    print("#LOC:%s" % country)
+    print("\n".join(sorted(countries[country])))
